Interface: CoreScaleOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: CoreScaleOptions

## # Hierarchy

- `CoreScaleOptions`

  ↳ `CartesianScaleOptions`

## # Properties

### # alignToPixels

• alignToPixels: `boolean`

Align pixel values to device pixels

#### # Defined in

index.esm.d.ts:1156
(opens new window)

### # display

• display: `boolean` | `"auto"`

Controls the axis global visibility (visible when true, hidden when false). When display: 'auto', the axis is visible only if at least one associated dataset is visible.

`default` true

#### # Defined in

index.esm.d.ts:1152
(opens new window)

### # reverse

• reverse: `boolean`

Reverse the scale.

`default` false

#### # Defined in

index.esm.d.ts:1161
(opens new window)

### # weight

• weight: `number`

The weight used to sort the axis. Higher weights are further away from the chart area.

`default` true

#### # Defined in

index.esm.d.ts:1166
(opens new window)

## # Methods

### # afterBuildTicks

▸ afterBuildTicks(`axis`): `void`

Callback that runs after ticks are created. Useful for filtering ticks.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1194
(opens new window)

### # afterCalculateLabelRotation

▸ afterCalculateLabelRotation(`axis`): `void`

Callback that runs after tick rotation is determined.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1210
(opens new window)

### # afterDataLimits

▸ afterDataLimits(`axis`): `void`

Callback that runs after data limits are determined.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1186
(opens new window)

### # afterFit

▸ afterFit(`axis`): `void`

Callback that runs after the scale fits to the canvas.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1218
(opens new window)

### # afterSetDimensions

▸ afterSetDimensions(`axis`): `void`

Callback that runs after dimensions are set.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1178
(opens new window)

### # afterTickToLabelConversion

▸ afterTickToLabelConversion(`axis`): `void`

Callback that runs after ticks are converted into strings.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1202
(opens new window)

### # afterUpdate

▸ afterUpdate(`axis`): `void`

Callback that runs at the end of the update process.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1222
(opens new window)

### # beforeBuildTicks

▸ beforeBuildTicks(`axis`): `void`

Callback that runs before ticks are created.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1190
(opens new window)

### # beforeCalculateLabelRotation

▸ beforeCalculateLabelRotation(`axis`): `void`

Callback that runs before tick rotation is determined.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1206
(opens new window)

### # beforeDataLimits

▸ beforeDataLimits(`axis`): `void`

Callback that runs before data limits are determined.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1182
(opens new window)

### # beforeFit

▸ beforeFit(`axis`): `void`

Callback that runs before the scale fits to the canvas.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1214
(opens new window)

### # beforeSetDimensions

▸ beforeSetDimensions(`axis`): `void`

Callback that runs before dimensions are set.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1174
(opens new window)

### # beforeTickToLabelConversion

▸ beforeTickToLabelConversion(`axis`): `void`

Callback that runs before ticks are converted into strings.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1198
(opens new window)

### # beforeUpdate

▸ beforeUpdate(`axis`): `void`

Callback called before the update process starts.

#### # Parameters

Name | Type
--- | ---
`axis` | `Scale`<`CoreScaleOptions`>

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:1170
(opens new window)